import 'dart:developer';

import 'package:example/configs/locator.dart';
import 'package:example/network/data_repository.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_simple_template_bloc/flutter_simple_template_bloc.dart';

class BaseBloc<Event, State> extends GenericBaseBloc<Event, State> {
  BaseBloc(super.state);

  DataRepository get dataRepository => locator<DataRepository>();

  @override
  void dismissLoading() {
    ServiceControlCenter.navigatorKey.currentState?.pop();
    super.dismissLoading();
  }

  @override
  void showPopUpDialog(
    String? title,
    String content,
    String? description,
    String? cancelTitle,
    String? buttonTitle,
    bool? barrierDismissible,
  ) {
    showDialog(
      context: ServiceControlCenter.navigatorKey.currentContext!,
      builder: (context) => AlertDialog(
        title: Text(
          title ?? tr('Text.alert'),
        ),
        content: Text(content),
      ),
    );
    super.showPopUpDialog(
      title,
      content,
      description,
      cancelTitle,
      buttonTitle,
      barrierDismissible,
    );
  }

  @override
  void showLoading() {
    showDialog(
      barrierDismissible: false,
      context: ServiceControlCenter.navigatorKey.currentContext!,
      builder: (BuildContext context) => WillPopScope(
        onWillPop: () async => false,
        child: const AlertDialog(
          backgroundColor: Colors.transparent,
          elevation: 0,
          content: CircularProgressIndicator(
            color: Colors.white,
          ),
        ),
      ),
    );
    super.showLoading();
  }

  @override
  void handleError(error) async {
    if (kDebugMode) {
      log('$error', name: 'HANDLE-ERROR');
    }
    super.handleError(error);
  }
}
