import 'package:flutter_simple_template_bloc/flutter_simple_template_bloc.dart';

class ApiBaseResponse<T> extends Response<T> {
  ApiBaseResponse({
    T? data,
    required RequestOptions requestOptions,
    int? statusCode,
    String? statusMessage,
    bool isRedirect = false,
    List<RedirectRecord> redirects = const [],
    Map<String, dynamic>? extra,
    Headers? headers,
  }) : super(
          data: data,
          requestOptions: requestOptions,
          statusCode: statusCode,
          statusMessage: statusMessage,
          isRedirect: isRedirect,
          redirects: redirects,
          headers: headers ?? Headers(),
          extra: extra ?? <String, dynamic>{},
        );

  factory ApiBaseResponse.fromJson(Map<String, dynamic> json) {
    return ApiBaseResponse(
      data: json["data"],
      requestOptions:
          RequestOptions(), // Cần cập nhật RequestOptions theo dữ liệu từ phản hồi
      statusCode: json['statusCode'],
      statusMessage: json['statusMessage'],
      isRedirect: json['isRedirect'],
      redirects: json['redirects'],
      headers: Headers.fromMap(json['headers'] ?? {}),
      extra: json['extra'],
    );
  }

  // Thêm phương thức toJson() nếu bạn cần chuyển đổi thành JSON
  Map<String, dynamic> toJson() {
    return {
      'statusCode': statusCode,
      'statusMessage': statusMessage,
      'isRedirect': isRedirect,
      'redirects': redirects,
      'headers': headers.map,
      'extra': extra,
    };
  }
}

// class BaseApiResponse<T> {
//   final T? data;
//   final RequestOptions requestOptions;
//   final int? statusCode;
//   final String? statusMessage;
//   final Headers headers;
//   final bool isRedirect;
//   final List<RedirectRecord> redirects;
//   final Map<String, dynamic>? extra;

//   Uri get realUri =>
//       redirects.isNotEmpty ? redirects.last.location : requestOptions.uri;

//   BaseApiResponse({
//     this.data,
//     required this.requestOptions,
//     this.statusCode,
//     this.statusMessage,
//     Headers? headers,
//     this.isRedirect = false,
//     this.redirects = const [],
//     this.extra = const <String, dynamic>{},
//   }) : headers = headers ?? Headers();

//   String toRawJson() => json.encode(toJson());

//   factory BaseApiResponse.toRawJson(String str) =>
//       BaseApiResponse.fromJson(json.decode(str));

//   factory BaseApiResponse.fromJson(Map<String, dynamic> json) =>
//       BaseApiResponse(
//         data: json["data"],
//         requestOptions: json["requestOptions"],
//         statusCode: json["statusCode"],
//         statusMessage: json["statusMessage"],
//         headers: json["headers"],
//         isRedirect: json["isRedirect"],
//         redirects: json["redirects"],
//         extra: json["extra"],
//       );

//   Map<String, dynamic> toJson() => {
//         "data": data,
//         "requestOptions": requestOptions,
//         "statusCode": statusCode,
//         "statusMessage": statusMessage,
//         "headers": headers,
//         "isRedirect": isRedirect,
//         "redirects": redirects,
//         "extra": extra,
//       };

//   @override
//   String toString() {
//     if (data is Map) {
//       return json.encode(data);
//     }
//     return super.toString();
//   }
// }
