import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';

extension ImageHelper on String {
  Widget loadImage({
    double? width,
    double? height,
    double? size,
    Color? color,
    BoxFit? boxFit,
  }) {
    if (size != null && size > 0) {
      width = size;
      height = size;
    }
    if (contains('http') || contains('https')) {
      return CachedNetworkImage(
        imageUrl: this,
        width: width,
        height: height,
        color: color,
        fit: boxFit,
        errorWidget: (context, url, error) => const Icon(Icons.error),
      );
    }
    if (contains('.svg')) {
      return SvgPicture.asset(
        this,
        width: width ?? 24,
        height: height ?? 24,
        fit: boxFit ?? BoxFit.contain,
      );
    }
    if (contains('.png') ||
        contains('.jpg') ||
        contains('jpeg') ||
        contains('.webp') ||
        contains('.gif')) {
      return Image.asset(
        this,
        width: width,
        height: height,
        color: color,
        fit: boxFit,
      );
    }
    throw 'Assest $this failed to load';
  }
}
