import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_simple_template_bloc/blocs/base_status.dart';
import 'package:flutter_simple_template_bloc/widgets/keep_alive_widget.dart';
import 'package:flutter_simple_template_bloc/widgets/loading_widget.dart';

abstract class BaseKeepAliveWidget<C extends BlocBase<State>, State>
    extends StatelessWidget {
  const BaseKeepAliveWidget({super.key});

  @override
  Widget build(BuildContext context) {
    WidgetsBinding.instance
        .addPostFrameCallback((_) => afterFirstLayout(context));
    init(context);
    return KeepAliveWidget(
      child: BlocListener<C, State>(
        listener: listener,
        child: BlocBuilder<C, State>(
          builder: (context, state) => Stack(
            children: [
              builder(context, state),
              LoadingWidget(isLoading: state == BaseStatus.loading),
            ],
          ),
        ),
      ),
    );
  }

  /// afterFirstLayout: This method will be triggerd when UI finished rendered at first time
  void afterFirstLayout(BuildContext context) {}

  /// Used for seting before return first build
  void init(BuildContext context) async {}

  /// Trigger src.bloc listener events, handle common events as default
  void listener(BuildContext context, State state);

  /// Get size of device
  Size getSize(BuildContext context) => MediaQuery.of(context).size;

  /// Get Theme of device
  TextTheme getTextTheme(BuildContext context) => Theme.of(context).textTheme;

  /// Provider UI builder based on state change
  Widget builder(BuildContext context, State state);

  // Show snack bar
  void showSnackbar();

  // show dialog
  void showDialogMessage();

  // hide keyboard
  void removeKeyBoard() {
    FocusManager.instance.primaryFocus?.unfocus();
  }
}
