import 'package:flutter/material.dart';
import 'package:shimmer/shimmer.dart';

class ShimmerLoadWidget extends StatelessWidget {
  final int length;
  final Color colorShimmer;
  final double opacityBaseColor;
  final double opacityHighlightColor;
  final double separator;
  final double heightRow;
  final EdgeInsets padding;

  const ShimmerLoadWidget({
    super.key,
    this.length = 10,
    this.colorShimmer = Colors.grey,
    this.opacityBaseColor = 0.3,
    this.opacityHighlightColor = 0.1,
    this.separator = 10.0,
    this.heightRow = 50.0,
    this.padding = const EdgeInsets.symmetric(
      horizontal: 20,
      vertical: 10,
    ),
  });

  @override
  Widget build(BuildContext context) {
    if (length == 1) {
      return Shimmer.fromColors(
        baseColor: colorShimmer.withOpacity(opacityBaseColor),
        highlightColor: colorShimmer.withOpacity(opacityHighlightColor),
        child: Container(
          margin: padding,
          height: heightRow,
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(14),
            color: Colors.white,
          ),
        ),
      );
    }
    return Shimmer.fromColors(
      baseColor: colorShimmer.withOpacity(opacityBaseColor),
      highlightColor: colorShimmer.withOpacity(opacityHighlightColor),
      child: ListView.separated(
        padding: padding,
        shrinkWrap: true,
        itemBuilder: (context, index) => Container(
          height: heightRow,
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(14),
            color: Colors.white,
          ),
        ),
        separatorBuilder: (context, index) => SizedBox(height: separator),
        itemCount: length,
      ),
    );
  }
}
